#! /bin/bash

. /opt/artixcs-mongo-dump/artixcs-mongo-dump.conf

echo "host=$host"
echo "port=$port"
echo "db=$db"
echo "excludeCollections=$excludeCollections"
echo "backupDir=$backupDir"
echo "useGzip=$useGzip"
echo "actualDays=${actualDays}"

logDir="/var/log/artix/artixcs-mongo-dump"
logFile="${logDir}/dump.log"
logReport="${logDir}/dump-report.log"

# если нет директории для логов, то создадим ее
[ ! -d $logDir ] && mkdir -p $logDir

# если не указана директория, в которую требуется сохранять бэкапы, то запишем ошибку и не будем выполнять бэкап
if [[ -z "$backupDir" ]]; then
    echo "$(date +%y.%m.%d_%H:%M:%S) Backup is failed" | tee -a ${logReport}
    echo "$(date +%y.%m.%d_%H:%M:%S) Error: param backupDir is empty" | tee -a ${logFile}
    exit 10
fi

# если директория с дампом уже есть и в ней есть файлы, то переименуем эту директорию
if [[ -d "${backupDir}/${db}" ]] && [[ "$(ls -A ${backupDir}/${db})" ]]; then
    echo "move ${backupDir}/${db} to archive" > ${logFile}
    mv ${backupDir}/${db} ${backupDir}/${db}_$(date +%y%m%d_%H%M%S)
fi

#удалим устаревшие дампы (старше actualDays дней)
find ${backupDir}/${db}_* -mtime +${actualDays} -type d -exec rm -rf {} +


# подготавливаем опции для создания дампа данных
commandOptions="--host=$host --port=$port -d $db -o $backupDir"

# если требуется архивация, то добавим ключ в строку запуска
if [[ "$useGzip" = 'true' ]]; then 
    commandOptions="${commandOptions} --gzip"
fi;

# если нужно исключить из дампа какие-то коллекции, то добавим соответствующие ключи
IFS=',' read -r -a excludeCollectionNames <<< "$excludeCollections"
for excludeCollection in "${excludeCollectionNames[@]}"
do
    commandOptions="${commandOptions} --excludeCollection=${excludeCollection}"
done

echo "$(date +%y.%m.%d_%H:%M:%S) start create backup: mongodump ${commandOptions}" >> ${logFile}
# запускаем бэкапирование
mongodump ${commandOptions} >> $logFile 2>&1
if [ $? -ne 0 ]; then
    echo "$(date +%y.%m.%d_%H:%M:%S) Backup is failed" | tee -a ${logReport}
else
    echo "$(date +%y.%m.%d_%H:%M:%S) Backup completed successfully!" | tee -a ${logReport}
fi
